freshbooks-api-client

module
v0.0.0-...-5af78e5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 22, 2024 License: MIT

README

Freshbooks API Client

Bitsnap Operational Intelligence Platform Freshbooks API client package.

Existing accounting platforms often suffer from reliability issues, such as potential ledger data loss and inconsistent API specifications, making long-term use and interoperability risky. To address these challenges, Yuriy is publishing up-to-date Accounting Services API Clients with a focus on long-term support. These clients aim to uncover and highlight inconsistencies in API specifications and documentation.

Bitsnap focuses on importing and data processing, instead of synchronization.

Refactoring

NOT READY FOR PRODUCTION USE.

Bitsnap Accounting Read-only API Clients

Usage

package main 

import (
  "time"
  
  "github.com/bitsnap/freshbooks-api-client-api-client"
)

// set FRESHBOOKS_API_TOKEN and FRESHBOOKS_SITE variables
//
func main() {

}

Development

Install asdf with all the dependencies

git clone https://github.com/asdf-vm/asdf.git ~/.asdf --branch v0.14.0
# Add the following to ~/.bashrc:
echo '. "$HOME/.asdf/asdf.sh"' >> ~/.bashrc
# Completions must be configured by adding the following to your .bashrc:
echo '. "$HOME/.asdf/completions/asdf.bash"' >> ~/.bashrc
# install asdf

asdf plugin add golang
asdf plugin add golangci-lint 
asdf plugin add ko
asdf plugin add goreleaser

go install golang.org/x/tools/cmd/goimports@latest
go install mvdan.cc/gofumpt@latest
go install github.com/onsi/ginkgo/v2/ginkgo@latest

Code generation

# will scrape the existing API documentation pages and emit the respective API client methods
# enums and models validation, where applicable

go generate ./...

Testing

FRESHBOOKS_API_TOKEN=test_xxx ginkgo run ./...

TODO

  • refactor scraping
  • maybe introduce some attr filtering
  • implement webhook API endpoints for CDC streaming
  • provide Apache Flink JNI source binding
  • provide Argo Events source binding
  • benchmarks

License

Bitsnap is a proprietary product developed by Yuriy Yarosh.

Freshbooks golang API Client is licensed under the terms of MIT License.

Directories

Path Synopsis
freshbooks

Jump to